@@ -30,6 +30,11 @@ class DescribeParametersRequest(RpcRequest):
 
 	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
 		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ExtraParam(self): # String
+		return self.get_query_params().get('ExtraParam')
+
+	def set_ExtraParam(self, ExtraParam):  # String
+		self.add_query_param('ExtraParam', ExtraParam)
 	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
